@@ -1,6 +1,6 @@
 #Flab
-#Version 1.1.0
-#Published 7-April-2022
+#Version 1.1.1
+#Published 11-April-2022
 #Distributed under GNU GPL v3
 #Author: Nicholas A. Jose
 
@@ -10,10 +10,10 @@ import os
 import sys
 
 class Flab(DeviceManager.DeviceManager, TaskManager.TaskManager, UiManager.UiManager):
-    #Flab inherits methods from DeviceManager, TaskManager and UiManager libraries
 
+    #Flab inherits methods from DeviceManager, TaskManager and UiManager libraries
     description = 'The Flab space for shared devices, tasks and user interfaces (UIs)'
-    version = '1.1.0'
+    version = '1.1.1'
     devices = {} #device dictionary
     tasks = {}  #task dictionary
     vars = {} #variable dictionary
@@ -106,4 +106,17 @@ class Flab(DeviceManager.DeviceManager, TaskManager.TaskManager, UiManager.UiMan
         add_directory(ui_dir, 'Actions')
         add_directory(ui_dir, 'Designs')
 
+    def set_working_directory(self,project_path):
+        try:
+            os.chdir(project_path)
+            cwd = os.getcwd()
+            par1 = os.path.abspath(os.path.join(cwd, '..'))
+            par2 = os.path.abspath(os.path.join(par1, '..'))
+            sys.path.append(par2)
+        except Exception as e:
+            print('Error in setting up project directory')
+            print(e)
+        finally:
+            pass
+
 
