@@ -1,6 +1,6 @@
 #TaskManager
-#Version 1.1.0
-#Published 7-April-2022
+#Version 1.1.1
+#Published 11-April-2022
 #Distributed under GNU GPL v3
 #Author: Nicholas A. Jose
 
@@ -17,9 +17,10 @@ class TaskManager():
 
     description = 'Methods for loading, running and terminating tasks implementing python\'s threading ' \
                   'library, PyQT\'s QThreading library, asyncio, and multiprocessing'
-    version = '1.1.0'
+    version = '1.1.1'
     tasks = {} #dictionary of loaded tasks
     running_tasks = {} #dictionary of running tasks (i.e. instances of threads)
+    load_all_tasks_completed = False
 
     def __init__(self):
         pass
@@ -31,7 +32,6 @@ class TaskManager():
             module_name = 'Projects.' + os.path.split(os.getcwd())[1]+'.Tasks.' + task_name
             mo = importlib.import_module(module_name)
             nt = mo.Task(self)
-
             #dictionary entry
             mod = {task_name:mo}
             ntd = {task_name:nt}
@@ -57,12 +57,18 @@ class TaskManager():
 
     #load every task present in the current project's Tasks folder
     def load_all_tasks(self):
-        cwd = os.getcwd()
-        tasks = glob.glob(cwd+'/Tasks/*.py')
-        task_names = []
-        for t in tasks:
-            task_names.append(t[len(cwd+'/Tasks/'):].replace('.py',''))
-        self.load_tasks(sorted(task_names))
+        try:
+            cwd = os.getcwd()
+            tasks = glob.glob(cwd+'/Tasks/*.py')
+            task_names = []
+            for t in tasks:
+                task_names.append(t[len(cwd+'/Tasks/'):].replace('.py',''))
+            self.load_tasks(sorted(task_names))
+        except Exception as e:
+            self.display(e)
+            self.display('Error in loading tasks')
+        finally:
+            self.load_all_tasks_completed = True
 
     #reload a single task into the flab
     def reload_task(self,task_name):
